searchNodes=[{"ref":"Wormwood.GQLCase.html","title":"Wormwood.GQLCase","type":"module","doc":"This module defines a few helpful macros when testing against an Absinthe GraphQL schema. It essentially registers an Absinthe schema and a GQL document to the module they&#39;re called in."},{"ref":"Wormwood.GQLCase.html#load_gql/2","title":"Wormwood.GQLCase.load_gql/2","type":"macro","doc":"Call this macro in the module you wish to load your GQL document in. It takes 2 arguments, the first is your Absinthe schema module, the second is a path to a GQL file that contains a GraphQL query or mutation. For example: defmodule MyCoolApplication.MyModule do load_gql MyCoolApplication.MyAbsintheSchema, &quot;assets/js/queries/MyQuery.gql&quot; # ..."},{"ref":"Wormwood.GQLCase.html#query_gql/1","title":"Wormwood.GQLCase.query_gql/1","type":"macro","doc":"Call this macro in the module you&#39;ve loaded a document into using load_gql or set_gql. Calling this will execute the document loaded into the module against the schema loaded in the module. It accepts a keyword list for options that are passed into Absinthe.run/3. Please see the Absinthe docs for more information on the options that can be passed to this macro. Returns a tuple of the query result from the Absinthe.run/3 call. For example: result = query_gql(variables: %{}, context: %{}) {:ok, query_data} = result"},{"ref":"Wormwood.GQLCase.html#query_gql_with_pipeline/2","title":"Wormwood.GQLCase.query_gql_with_pipeline/2","type":"macro","doc":"Call this macro in the module you&#39;ve loaded a document into using load_gql or set_gql. Calling this will execute the document loaded into the module against the schema loaded in the module. Absinthe will use the phases in the &quot;pipeline_phases&quot; list argument when running. It also accepts a keyword list for options that are passed into Absinthe.run/3. Please see the Absinthe docs for more information on the options that can be passed to this macro. Returns a tuple of the query result from the Absinthe.Pipeline.run/2 call. For example: pipeline = [Absinthe.Phase.Parse, Absinthe.Phase.Blueprint] result = query_gql_with_pipeline(pipeline) assert {:ok, %Absinthe.Blueprint{} = _blueprint, _pipeline} = result"},{"ref":"Wormwood.GQLCase.html#set_gql/2","title":"Wormwood.GQLCase.set_gql/2","type":"macro","doc":"Call this macro in the module where you want to query using a static string as your query. It takes 2 arguments, the first is your Absinthe schema module, the second is a string of a GQL query or mutation. This still supports imports, they will be resolved from the current working directory. (Most likely the top level of your app) For example: defmodule MyCoolApplication.MyModule do set_gql MyCoolApplication.MyAbsintheSchema, &quot;query { some { cool { gql { id } }}}&quot; # ..."},{"ref":"Wormwood.GQLLoader.html","title":"Wormwood.GQLLoader","type":"module","doc":""},{"ref":"Wormwood.GQLLoader.html#load_file!/1","title":"Wormwood.GQLLoader.load_file!/1","type":"function","doc":"When provided a path to a GQL document, expands all import statements and attempts to parses it with Absinthe. Returns the query string source with imports appended. For example: load_file!(&quot;assets/js/MyQuery.gql&quot;)"},{"ref":"Wormwood.GQLLoader.html#load_string!/1","title":"Wormwood.GQLLoader.load_string!/1","type":"function","doc":"When provided the source code of a GQL document, expands all import statements and attempts to parses it with Absinthe. Returns the query string source with imports appended. For example: load_string!(@my_query_source)"},{"ref":"WormwoodImportError.html","title":"WormwoodImportError","type":"exception","doc":"An exception raised by Wormwood when it cannot find a file imported via an #import &quot;some_file.gql&quot; statement"},{"ref":"WormwoodImportError.html#message/1","title":"WormwoodImportError.message/1","type":"function","doc":"Callback implementation for Exception.message/1."},{"ref":"WormwoodLoaderError.html","title":"WormwoodLoaderError","type":"exception","doc":"An exception that is raised when Wormwood can&#39;t find or access a file"},{"ref":"WormwoodLoaderError.html#message/1","title":"WormwoodLoaderError.message/1","type":"function","doc":"Callback implementation for Exception.message/1."},{"ref":"WormwoodParseError.html","title":"WormwoodParseError","type":"exception","doc":"An exception that is raised when Wormwood gets a bad result from Absinthe&#39;s Parse phase. It should provide some useful information as to where the error lays in the document."},{"ref":"WormwoodParseError.html#message/1","title":"WormwoodParseError.message/1","type":"function","doc":"Callback implementation for Exception.message/1."},{"ref":"WormwoodSetupError.html","title":"WormwoodSetupError","type":"exception","doc":"An exception that is raised when Wormwood is called improperly"},{"ref":"WormwoodSetupError.html#message/1","title":"WormwoodSetupError.message/1","type":"function","doc":"Callback implementation for Exception.message/1."},{"ref":"readme.html","title":"Wormwood","type":"extras","doc":"Wormwood Wormwood is a tiny library to aid in testing GraphQL queries against an Absinthe schema. It allows you to test your query documents inside ExUnit test modules, and requires no HTTP requests to occur during testing. Why Wormwood? We believe that testing GraphQL queries should be easy. Wormwood lets you scope a test module to one single document (paired with a schema) with ease, and helps to remove any of the boilerplate code such a task would introduce. With Wormwood, you simply load your document at the top of your module, and query it using a standard function. That&#39;s it! Installation Install from Hex.pm: def deps do [{:wormwood, &quot;~&gt; 0.1.0&quot;}] end Getting Started Install Wormwood! use the Wormwood GQLCase inside the test module... defmodule MyCoolApplication.MyTestCase do use ExUnit.Case use Wormwood.GQLCase #... Use the Wormwood load_gql/2 macro to specify your schema and load your GraphQL document... defmodule MyCoolApplication.MyTestCase do #... load_gql MyCoolApplication.MyAbsintheSchema, &quot;assets/js/queries/MyQuery.gql&quot; #... Your document and schema are ready to go, you can now call query_gql/1 inside any of your test statements to execute the loaded document against the specified schema. You can pass options to this call, please refer to the Absinthe docs for more information on options. For Example: #... test &quot;should be a valid query&quot; do result = query_gql(variables: %{}, context: %{:current_user =&gt; some_user}) assert {:ok, _query_data} = result end #... Full example from the above steps: defmodule MyCoolApplication.MyTestCase do use ExUnit.Case use Wormwood.GQLCase load_gql MyCoolApplication.MyAbsintheSchema, &quot;assets/js/queries/MyQuery.gql&quot; test &quot;should be a valid query&quot; do result = query_gql(variables: %{}, context: %{:current_user =&gt; some_user}) assert {:ok, _query_data} = result end end Examples Check out lib/examples/ for a very simple, static, and self contained Absinthe schema. You can also dig around in test/examples/ for simple tests that query against that sample schema using Wormwood. License Copyright © 2019 Tinfoil Security Inc. This project is MIT licensed. Made with ❤️ and 🔐 by Tinfoil Security"}]